@@ -42,31 +42,41 @@ typedef struct {
 
 /* Number display mode. */
 typedef enum {
-  FIX,
-  SCI,
-  ENG
-} DisplayFormat;
+    MP_DISPLAY_FORMAT_AUTOMATIC,
+    MP_DISPLAY_FORMAT_FIXED,
+    MP_DISPLAY_FORMAT_SCIENTIFIC,
+    MP_DISPLAY_FORMAT_ENGINEERING
+} MpDisplayFormat;
 
 GType mp_serializer_get_type(void);
-MpSerializer *mp_serializer_new(void);
 
-void mp_serializer_to_standard_string(MpSerializer *serializer, const MPNumber *z, char **target);
-void mp_serializer_to_specific_string(const MPNumber *z, int base, int accuracy, bool trim_zeroes, bool localize, char **target);
-bool mp_serializer_from_string(MpSerializer *serializer, const char *str, MPNumber *z);
+MpSerializer *mp_serializer_new(MpDisplayFormat format, int base, int accuracy);
+
+gchar *mp_serializer_to_string(MpSerializer *serializer, const MPNumber *z);
+gboolean mp_serializer_from_string(MpSerializer *serializer, const gchar *str, MPNumber *z);
+
+void mp_serializer_set_number_format(MpSerializer *serializer, MpDisplayFormat format);
+MpDisplayFormat mp_serializer_get_number_format(MpSerializer *serializer);
 
-const gchar* mp_serializer_get_thousands_separator_text(MpSerializer *serializer);
-const gchar* mp_serializer_get_numeric_point_text(MpSerializer *serializer);
-gboolean mp_serializer_is_numeric_point(MpSerializer *serializer, const char* text);
 void mp_serializer_set_base(MpSerializer *serializer, int base);
 int mp_serializer_get_base(MpSerializer *serializer);
-gboolean mp_serializer_get_show_trailing_zeroes(MpSerializer *serializer);
-void mp_serializer_set_show_trailing_zeroes(MpSerializer *serializer, gboolean visible);
-gboolean mp_serializer_get_show_thousands_separators(MpSerializer *serializer);
-void mp_serializer_set_show_thousands_separators(MpSerializer *serializer, gboolean visible);
-int mp_serializer_get_accuracy(MpSerializer *serializer);
+
 void mp_serializer_set_accuracy(MpSerializer *serializer, int accuracy);
-DisplayFormat mp_serializer_get_number_format(MpSerializer *serializer);
-void mp_serializer_set_number_format(MpSerializer *serializer, DisplayFormat format);
+int mp_serializer_get_accuracy(MpSerializer *serializer);
+
+void mp_serializer_set_radix(MpSerializer *serializer, gunichar radix);
+gunichar mp_serializer_get_radix(MpSerializer *serializer);
+
+void mp_serializer_set_thousands_separator(MpSerializer *serializer, gunichar separator);
+gunichar mp_serializer_get_thousands_separator(MpSerializer *serializer);
+
+gint mp_serializer_get_thousands_separator_count(MpSerializer *serializer);
+
+void mp_serializer_set_show_trailing_zeroes(MpSerializer *serializer, gboolean visible);
+gboolean mp_serializer_get_show_trailing_zeroes(MpSerializer *serializer);
+
+void mp_serializer_set_show_thousands_separators(MpSerializer *serializer, gboolean visible);
+gboolean mp_serializer_get_show_thousands_separators(MpSerializer *serializer);
 
 G_END_DECLS
 
