@@ -23,7 +23,7 @@
 #include <libintl.h>
 
 #include "mp.h"
-#include "mp-internal.h"
+#include "mp-private.h"
 
 static int
 mp_compare_mp_to_int(const MPNumber *x, int i)
@@ -557,6 +557,7 @@ mp_tanh(const MPNumber *x, MPNumber *z)
     } else {
         mp_epowy(&t, &t);
         mp_add_integer(&t, 1, z);
+        mp_add_integer(&t, -1, &t);
         mp_divide(&t, z, z);
     }
 
@@ -588,7 +589,7 @@ mp_acosh(const MPNumber *x, MPNumber *z)
     mp_set_from_integer(1, &t);
     if (mp_is_less_than(x, &t)) {
         /* Translators: Error displayed when inverse hyperbolic cosine value is undefined */
-        mperr(_("Inverse hyperbolic cosine is undefined for values less than or equal to one"));
+        mperr(_("Inverse hyperbolic cosine is undefined for values less than one"));
         mp_set_from_integer(0, z);
         return;
     }
